#!/bin/sh
CONF=/etc/config/qpkg.conf																						# Location of QPKG conf file
QPKG_NAME="PlexMediaServer"																						# Name of PMS install dir
QPKG_DIR=$(getcfg -f $CONF $QPKG_NAME Install_path)										# Grap PMS install dir, regardless of disk layout

case "$1" in
  start)
    ENABLED=$(/sbin/getcfg $QPKG_NAME Enable -u -d FALSE -f $CONF)
    if [ "$ENABLED" != "TRUE" ]; then
        echo "$QPKG_NAME is disabled."
        exit 1
    fi
	
	if [ -f ${QPKG_DIR}/Library/Plex\ Media\ Server/plexmediaserver.pid ]; then
		echo "Plex Media Server is currently running or hasn't been shutdown properly. Please stop it before starting a new instance."
		echo "If not so, then delete the file named ${QPKG_DIR}/Library/Plex\ Media\ Server/plexmediaserver.pid and try again."
		exit 0
	fi
	echo "Starting Plex Media Server ..."
	export PLEX_MEDIA_SERVER_MAX_PLUGIN_PROCS=6
	export LC_ALL=en_US.UTF-8
	export LANG=en_US.UTF-8
	export LANGUAGE=en_US.UTF-8
	export PLEX_MEDIA_SERVER_APPLICATION_SUPPORT_DIR="${QPKG_DIR}/Library"
	export TMPDIR="${QPKG_DIR}/Library/tmp"
	export LD_LIBRARY_PATH=${QPKG_DIR}
	#Wait a little bit, since new firmware seems to cause a race condition
	sleep 5
	ulimit -s 3000
	cd ${QPKG_DIR}
	./Plex\ Media\ Server &
		
    ;;

  stop)

	if [ ! -f ${QPKG_DIR}//Library/Plex\ Media\ Server/plexmediaserver.pid ]; then
		echo "Plex Media Server hasn't been enabled or started ..."
		exit 0
	else 
		echo "Stopping Plex Media Server ..."
		for KILLPID in `ps ax | grep '[P]lex Media Server' | awk ' { print $1;}'`; do 
			echo "Killing process $KILLPID"
	  		kill $KILLPID;
		done
	fi		
    ;;

  restart)
    $0 stop
		sleep 5
    $0 start
    ;;

  *)
    echo "Usage: $0 {start|stop|restart}"
    exit 1
esac

exit 0
